@@ -13,7 +13,7 @@ typedef Eo Efl_Model;
 
 /** EFL model property event data structure
  *
- * @ingroup Efl_Model
+ * @ingroup Efl
  */
 typedef struct _Efl_Model_Property_Event
 {
@@ -22,6 +22,21 @@ typedef struct _Efl_Model_Property_Event
                                        */
 } Efl_Model_Property_Event;
 
+/** Every time a child is added the event EFL_MODEL_EVENT_CHILD_ADDED is
+ * dispatched passing along this structure.
+ *
+ * @ingroup Efl
+ */
+typedef struct _Efl_Model_Children_Event
+{
+  unsigned int index; /**< index is a hint and is intended to provide a way for
+                       * applications to control/know children relative
+                       * positions through listings. */
+  Efl_Object *child; /**< If an object has been built for this index and it is
+                      * currently tracked by the parent, it will be available
+                      * here. */
+} Efl_Model_Children_Event;
+
 
 #endif
 /** Efl model interface
@@ -42,13 +57,15 @@ EWAPI const Efl_Class *efl_model_interface_get(void);
  *
  * See also @ref EFL_MODEL_EVENT_PROPERTIES_CHANGED.
  *
+ * @param[in] obj The object.
+ *
  * @return Array of current properties
  *
  * @since 1.14
  *
  * @ingroup Efl_Model
  */
-EOAPI const Eina_Array *efl_model_properties_get(const Eo *obj);
+EOAPI Eina_Array *efl_model_properties_get(const Eo *obj);
 
 /**
  * @brief Set a property value of a given property name.
@@ -64,16 +81,18 @@ EOAPI const Eina_Array *efl_model_properties_get(const Eo *obj);
  *
  * See @ref efl_model_property_get, @ref EFL_MODEL_EVENT_PROPERTIES_CHANGED
  *
+ * @param[in] obj The object.
  * @param[in] property Property name
- * @param[in] value New value
+ * @param[in] value Property value
  *
- * @return Future returning the recorded value or error
+ * @return Return an error in case the property could not be set, the value
+ * that was set otherwise.
  *
  * @since 1.14
  *
  * @ingroup Efl_Model
  */
-EOAPI Efl_Future *efl_model_property_set(Eo *obj, const char *property, const Eina_Value *value);
+EOAPI Eina_Future *efl_model_property_set(Eo *obj, const char *property, Eina_Value *value);
 
 /**
  * @brief Retrieve the value of a given property name.
@@ -84,62 +103,65 @@ EOAPI Efl_Future *efl_model_property_set(Eo *obj, const char *property, const Ei
  *
  * See @ref efl_model_properties_get, @ref EFL_MODEL_EVENT_PROPERTIES_CHANGED
  *
+ * @param[in] obj The object.
  * @param[in] property Property name
  *
- * @return Future of the value that was got
+ * @return Property value
  *
  * @since 1.14
  *
  * @ingroup Efl_Model
  */
-EOAPI Efl_Future *efl_model_property_get(Eo *obj, const char *property);
+EOAPI Eina_Value *efl_model_property_get(const Eo *obj, const char *property);
 
 /**
  * @brief Get children slice OR full range.
  *
  * children_slice_get behaves in two different ways, it may provide the slice
- * if both @c start AND @c count are non-zero OR full range otherwise.
+ * if @c count is non-zero OR full range otherwise.
  *
  * Since 'slice' is a range, for example if we have 20 childs a slice could be
- * the range from 3(start) to 4(count), see:
+ * the range from 3(start) with 4(count), see:
  *
- * child 0  [no] child 1  [no] child 2  [yes] child 3  [yes] child 4  [yes]
- * child 5  [yes] child 6  [no] child 7  [no]
+ * child 0  [no] child 1  [no] child 2  [no] child 3  [yes] child 4  [yes]
+ * child 5  [yes] child 6  [yes] child 7  [no]
  *
  * Optionally the user can call children_count_get to know the number of
  * children so a valid range can be known in advance.
  *
  * See @ref efl_model_children_count_get
  *
- * @param[in] start Range begin - start from here. If start and count are 0
- * slice is ignored.
- * @param[in] count Range size. If count and start are 0 slice is ignored.
+ * @param[in] obj The object.
+ * @param[in] start Range begin - start from here.
+ * @param[in] count Range size. If count is 0, start is ignored.
  *
- * @return Future of the children
+ * @return Array of childrens
  *
  * @since 1.14
  *
  * @ingroup Efl_Model
  */
-EOAPI Efl_Future *efl_model_children_slice_get(Eo *obj, unsigned int start, unsigned int count);
+EOAPI Eina_Future *efl_model_children_slice_get(Eo *obj, unsigned int start, unsigned int count);
 
 /**
  * @brief Get children count.
  *
- * When efl_model_load is completed efl_model_coildren_count_get can be use to
+ * When efl_model_load is completed efl_model_coildren_count_get can be used to
  * get the number of children. children_count_get can also be used before
  * calling children_slice_get so a valid range is known. Event
  * EFL_MODEL_CHILDREN_COUNT_CHANGED is emitted when count is finished.
  *
  * See also @ref efl_model_children_slice_get.
  *
- * @return Future of the children count
+ * @param[in] obj The object.
+ *
+ * @return Current known children count
  *
  * @since 1.14
  *
  * @ingroup Efl_Model
  */
-EOAPI Efl_Future *efl_model_children_count_get(Eo *obj);
+EOAPI unsigned int efl_model_children_count_get(const Eo *obj);
 
 /**
  * @brief Add a new child.
@@ -149,6 +171,8 @@ EOAPI Efl_Future *efl_model_children_count_get(Eo *obj);
  * EFL_MODEL_EVENT_CHILD_ADDED is then raised and the new child is kept along
  * with other children.
  *
+ * @param[in] obj The object.
+ *
  * @return Child object
  *
  * @since 1.14
@@ -164,6 +188,7 @@ EOAPI Efl_Object *efl_model_child_add(Eo *obj);
  * the event @ref EFL_MODEL_EVENT_CHILD_REMOVED is then raised to give a chance
  * for listeners to perform any cleanup and/or update references.
  *
+ * @param[in] obj The object.
  * @param[in] child Child to be removed
  *
  * @since 1.14
@@ -184,7 +209,7 @@ EWAPI extern const Efl_Event_Description _EFL_MODEL_EVENT_PROPERTIES_CHANGED;
 EWAPI extern const Efl_Event_Description _EFL_MODEL_EVENT_CHILD_ADDED;
 
 /** Event dispatched when new child is added.
- * @return Efl_Object *
+ * @return Efl_Model_Children_Event
  *
  * @ingroup Efl_Model
  */
@@ -193,7 +218,7 @@ EWAPI extern const Efl_Event_Description _EFL_MODEL_EVENT_CHILD_ADDED;
 EWAPI extern const Efl_Event_Description _EFL_MODEL_EVENT_CHILD_REMOVED;
 
 /** Event dispatched when child is removed.
- * @return Efl_Object *
+ * @return Efl_Model_Children_Event
  *
  * @ingroup Efl_Model
  */
